@@ -241,7 +241,7 @@ class Task:
         return key
 
     def __repr__(self):
-        return "[{}: {}: {}]".format(self.__class__.__name__, self.key, self.task_data)
+        return "[{}: {}: {}]".format(self.__class__.__name__, self.key, repr(self.task_data)[:300])
 
     def filename_instance(self):
         return "unset"
@@ -285,12 +285,17 @@ def order_nested_dict(d):
 
 
 class Queue:
+    current_task=None
+    queue=None
+
+    def __repr__(self):
+        return f"[{self.__class__.__name__}: {self.queue} @ {self.current_task} ]"
+
     def list_queues(self, pattern=None):
         return list_queues(pattern)
 
     def __init__(self,queue="default", worker_id=None):
         ""
-        self.logger = logging.getLogger(repr(self))
 
         if worker_id is None:
             self.worker_id=self.get_worker_id()
@@ -300,6 +305,7 @@ class Queue:
         self.queue=queue
         self.current_task=None
         self.current_task_status=None
+        self.logger = logging.getLogger(repr(self))
 
     def find_task_instances(self, task: Task, klist: Union[list, None]=None) -> List[types.TaskEntry]:
         ""
@@ -561,20 +567,42 @@ class Queue:
         logger.warning('this is very desctructive: clearing event log')
         EventLog.delete().execute(database=None)
 
-    def move_task(self, fromk, tok, task, update_entry=False):
-        ""
+    def move_task(self, fromk, tok, task, update_entry=False, n_tries_left=1):
+        "moves task"
 
+        retry_delay=2
+
+        if n_tries_left<=0:
+            return
+            
         extra = {}
         if update_entry:
             extra = {TaskEntry.task_dict_string: self.current_task.serialize()}
 
-        r=TaskEntry.update({
-                        TaskEntry.state:tok,
-                        TaskEntry.worker_id:self.worker_id,
-                        TaskEntry.modified:datetime.datetime.now(),
-                        **extra
-                    })\
-                    .where(TaskEntry.state==fromk, TaskEntry.key==task.key).execute(database=None)
+        try:
+
+            r=TaskEntry.update({
+                            TaskEntry.state:tok,
+                            TaskEntry.worker_id:self.worker_id,
+                            TaskEntry.modified:datetime.datetime.now(),
+                            **extra
+                        })\
+                        .where(TaskEntry.state==fromk, TaskEntry.key==task.key).execute(database=None)
+
+        except Exception as e:
+            logger.error('failed to move task: %s', repr(e))
+            #self.log_task("failed to move task from %s to %s; serialized to %i"%(repr(e),len(serialized)),state="failed_to_lock")
+            self.log_task(f"failed to move task from {fromk} to {tok}: {e.__class__}:{repr(e)}; db: {db } - will try connecting after {retry_delay} s", state="failed_to_lock")
+
+            time.sleep(retry_delay + (30 - n_tries_left))
+
+            try:
+                db.connect()
+                self.log_task(f"managed to reconnect! {repr(e)}", state="db_reconnected")
+            except peewee.OperationalError as e:
+                self.log_task(f"failed to reconnect! {repr(e)}", state="failed_to_reconnect")
+
+            return self.move_task(fromk, tok, task, update_entry, n_tries_left-1)
 
     def purge(self):
         ""
@@ -702,14 +730,22 @@ class Queue:
             raise Exception(f"depends_on has unknown type {depends_on.__class__}, expected list")
 
         log("locking task",self.current_task)
-        self.log_task(f"task to lock by {len(depends_on)} dependencies",state="locked")
+        self.log_task(f"task to lock by {len(depends_on)} dependencies", state="locking")
         if self.current_task is None:
             raise Exception("task must be available to lock")
 
-        self.current_task.depends_on = [] 
+        _depends_on = [] 
         
         for dependency in depends_on:
-            dependency_key = Task(dependency).key
+            self.log_task(f"constructing dependency key for: {repr(dependency)[:100]}...", state="locking")
+            try:
+                dependency_key = Task(dependency).key
+            except Exception as e:
+                logger.error(f"problem constructing dependency key {e}")
+                self.log_task(f"problem constructing dependency key {e}", state="locking")
+                raise
+
+            self.log_task(f"constructed dependency key: {dependency_key}", state="locking")
 
             #dependency_task = self.task_by_key(dependency_key)
 
@@ -717,28 +753,20 @@ class Queue:
                         task_key=dependency_key,
                     )
 
-            self.current_task.depends_on.append(dependency_reference)
+            _depends_on.append(dependency_reference)
+        
+        self.current_task.depends_on = _depends_on
 
-        serialized=self.current_task.serialize()
+        try:
+            serialized=self.current_task.serialize()
+        except Exception as e:
+            logger.error("problem serializing task: %s", e)
+            self.log_task(f"problem serializing task: {e}", state="locking")
+            raise
 
         self.log_task("task to lock: serialized to %i"%len(serialized), state="locked")
 
-        n_tries_left=10
-        retry_delay=2
-        while n_tries_left>0:
-            try:
-
-                self.move_task('running', 'locked', self.current_task, update_entry=True)
-
-            except Exception as e:
-                log('failed to lock:',repr(e))
-                self.log_task("task to failed lock: %s; serialized to %i"%(repr(e),len(serialized)),state="failed_to_lock")
-                time.sleep(retry_delay)
-                if n_tries_left==1:
-                    raise
-                n_tries_left-=1
-            else:
-                break
+        self.move_task('running', 'locked', self.current_task, update_entry=True, n_tries_left=30)
         
         self.log_task("task locked from "+str(self.current_task_status),state="locked")
 
@@ -883,6 +911,8 @@ class Queue:
         if state is None:
             state="undefined"
 
+        logger.info("log_task: %s:%s for %s at %s", task, task_key, message, state)
+
         return EventLog.insert(
                              queue=self.queue,
                              task_key=task_key,
