@@ -17,6 +17,8 @@ import dqueue.typing as types
 from typing import Union
 from dqueue import tools
 
+from retrying import retry
+
 from bravado.client import SwaggerClient, RequestsClient
 
 
@@ -32,8 +34,8 @@ class QueueProxy(Queue):
         if self._token is None:
             for n, m in [
                     ("env", lambda: os.environ.get('DDA_TOKEN').strip()), # type: ignore
-                    ("home-dotfile", lambda: open(os.environ.get('HOME')+"/.dda-token").read()), # type: ignore
-                    ("cwd-dotfile", lambda: open(".dda-token").read()), # type: ignore
+                    ("home-dotfile", lambda: open(os.environ.get('HOME')+"/.dda-token").read().decode().strip()), # type: ignore
+                    ("cwd-dotfile", lambda: open(".dda-token").read().decode().strip()), # type: ignore
                     ]:
                 try:
                     print("trying", n)
@@ -50,7 +52,7 @@ class QueueProxy(Queue):
         return self._token
 
     def __repr__(self):
-        return f"[ {self.__class__.__name__}: {self.leader}@{self.queue} ]"
+        return f"[ {self.__class__.__name__}: {self.leader}@{self.queue} : {self.current_task} ]"
 
     def __init__(self, queue_uri="http://localhost:5000@default"):
         super().__init__()
@@ -62,6 +64,7 @@ class QueueProxy(Queue):
         self.leader = r.groups()[0]
         self.queue = r.groups()[1]
 
+        self.logger = logging.getLogger(repr(self))
 
     def list_queues(self, pattern):
         print(self.client.queues.list().response().result)
@@ -122,7 +125,7 @@ class QueueProxy(Queue):
                                    worker_id=self.worker_id,
                                    token=self.token).response().result
     
-    def log_task(self, message, task=None, state=None, task_key=None):
+    def log_task(self, message, task=None, state="unset", task_key=None):
         self.logger.info("log_task %s", message)
 
         if task_key is None:
@@ -131,12 +134,30 @@ class QueueProxy(Queue):
 
             task_key = task.key
 
-        return self.client.worker.logTask(message=message, 
-                                   task_key=task_key, 
-                                   state=state, 
-                                   queue=self.queue, 
-                                   worker_id=self.worker_id,
-                                   token=self.token).response().result
+        def _log_task():
+            return self.client.worker.logTask(message=message, 
+                               task_key=task_key, 
+                               state=state, 
+                               queue=self.queue, 
+                               worker_id=self.worker_id,
+                               token=self.token).response().result
+
+        def retry_on_exception(exception):
+            self.logger.error("%s: error in client log_task: %s; trying to send %s %s %s %s %s %s", self, exception,
+                        message,
+                        task_key,
+                        state,
+                        self.queue,
+                        self.worker_id,
+                        self.token,
+                    )
+            return True
+
+        return retry(
+                    wait_exponential_multiplier=1000, 
+                    wait_exponential_max=300000,
+                    retry_on_exception=retry_on_exception,
+                )(_log_task)()
 
     def insert_task_entry(self,task,state):
         raise NotImplementedError
